@@ -1,7 +1,7 @@
 package Khonsu;
 use strict;
 use warnings;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use PDF::API2;
 
 use Khonsu::File;
@@ -29,16 +29,12 @@ Khonsu - PDF Generation!
 
 =head1 VERSION
 
-Version 0.04
+Version 0.07
 
 =cut
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
-
 	my @words = ('Aker', 'Anubis', 'Hapi', 'Khepri', 'Maahes', 'Thoth', 'Bastet', 'Hatmehit', 'Tefnut', 'Menhit', 'Imentet');
 
 	my $generate_text = sub {
@@ -112,34 +108,141 @@ Perhaps a little code snippet.
 		h => $khonsu->page->h - $page_padding,
 	)->add_page;
 
-	$khonsu->add_toc(
-		x => $padding,
-		y => $padding,
-		w => $khonsu->page->w - $page_padding,
-		h => $khonsu->page->h - $page_padding
-	);
+	$khonsu->add_toc();
+
+	for (0 .. 100) {
+		$khonsu->add_h1(
+			text => $generate_text->(3),
+			toc => 1,
+		)->add_text(
+			text => $generate_text->(2000),
+			indent => 4,
+			font => {
+				colour => '#fff'
+			},
+		);
+	}
 
 	$khonsu->add_h1(
-		text => $generate_text->(3),
-		x => $padding,
-		y => $padding,
-		w => $khonsu->page->w - $page_padding,
-		toc => 1,
-	)->add_text(
-		text => $generate_text->(2000),
-		x => $padding,
-		y => ($page_padding) + $khonsu->h1->line_height,
-		w => $khonsu->page->w - $page_padding,
-		h => $khonsu->page->h - ($khonsu->h1->line_height + $page_padding + $padding),
-		indent => 4,
-		font => {
-			colour => '#fff'
-		},
-		overflow => 1,
+		text => 'A simple form',
+		toc => 1
 	);
-	
+
+	$khonsu->add_input(
+		text => 'Name:'
+	);
+
+	$khonsu->add_select(
+		text => 'Colour:',
+		options => [qw/red yellow green/]
+	);
+
 	$khonsu->save();
 
+=head1 METHODS
+
+=cut
+
+=head2 add_page
+
+=cut
+
+=head2 open_page
+
+=cut
+
+=head2 add_page_header
+
+=cut
+
+=head2 add_page_footer
+
+=cut
+
+=head2 remove_page_header_and_footer 
+
+=cut
+
+=head2 remove_page_header
+
+=cut
+
+=head2 remove_page_footer
+
+=cut
+
+=head2 add_toc
+
+=cut
+
+=head2 add_text
+
+=cut
+
+=head2 add_h1
+
+=cut
+
+=head2 add_h2
+
+=cut
+
+=head2 add_h3
+
+=cut
+
+=head2 add_h4
+
+=cut
+
+=head2 add_h5
+
+=cut
+
+=head2 add_h6
+
+=cut
+
+=head2 add_image
+
+=cut
+
+=head2 add_form
+
+=cut
+
+=head2 add_input
+
+=cut
+
+=head2 add_select
+
+=cut
+
+=head2 add_line
+
+=cut
+
+=head2 add_box
+
+=cut
+
+=head2 add_circle
+
+=cut
+
+=head2 add_pie
+
+=cut
+
+=head2 add_ellipse
+
+=cut
+
+=head2 load_font
+
+=cut
+
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
