@@ -20,15 +20,25 @@ sub attributes {
 
 sub add {
 	my ($self, $file, %attributes) = @_;
+	if (!$attributes{x}) {
+		$attributes{x} = $file->page->x;
+		$attributes{y} = $file->page->y;
+		$attributes{h} = $attributes{h} || $file->page->remaining_height();
+		$attributes{w} = $attributes{w} || $file->page->width();
+	}
 	$self->set_attributes(%attributes);
 	my $type = $self->_identify_type();
 	my $image = $file->pdf->$type($self->image);
 	my %points = $self->get_points();
 	my $photo = $file->page->current->gfx;
+	if ($attributes{align} && $attributes{align} eq 'center') {
+		$points{x} = ($file->page->w - $points{w}) / 2;
+	}
 	$photo->image(
 		$image,
-		$points{x}, $points{y}, $points{w}, $points{h}
+		$points{x}, $file->page->h - ($points{y} + $points{h}), $points{w}, $points{h}
 	);
+	$file->page->y($points{y} + $points{h});	
 	return $file;
 }
 
