@@ -25,6 +25,7 @@ use Khonsu::Image;
 
 use Khonsu::Form;
 use Khonsu::Form::Field::Input;
+use Khonsu::Form::Field::Select;
 
 use Khonsu::TOC;
 
@@ -98,7 +99,9 @@ use constant FORM => (
 use constant INPUT => (
 	input => {is => 'rw', isa => Object, default => sub { Khonsu::Form::Field::Input->new() }}
 );
-
+use constant SELECT => (
+	select => {is => 'rw', isa => Object, default => sub { Khonsu::Form::Field::Select->new() }}
+);
 sub new {
 	my ($pkg, %params) = @_;
 
