@@ -12,6 +12,7 @@ sub attributes {
 		pad_end => {$a->RW, $a->STR},
 		align => {$a->RW, $a->STR, default => sub { 'left' }},
 		end_w => {$a->RW, $a->NUM},
+		margin => {$a->RW, $a->NUM, default => sub { 5 }},
 		$a->FONT,
 		$a->POINTS
 	);
@@ -21,6 +22,13 @@ sub add {
 	my ($self, $file, %attributes) = @_;
 
 	my $font = $self->font->load($file, %{ delete $attributes{font} || {} });
+
+	if (!$attributes{x} && !$attributes{align}) {
+		$attributes{x} = $file->page->x;
+		$attributes{y} = $file->page->y;
+		$attributes{h} = $file->page->remaining_height();
+		$attributes{w} = $file->page->width();
+	}
 	
 	$self->set_attributes(%attributes);
 
@@ -38,7 +46,7 @@ sub add {
 	);
 
 	my $ypos = $file->page->h - ($pos{y} + $pos{l});
-
+	
 	my $max_height = $ypos - $pos{h};
 
 	my $xpos = $pos{x};
@@ -55,7 +63,7 @@ sub add {
 		unshift @words, map { " " } 0 .. $indent;
 	}
 
-	while ($ypos > $max_height && @words) {
+	while ($ypos - $pos{l} >= $max_height && @words) {
 		my $word = shift @words;
 		my ($width, @line) = ($text->advancewidth($word), ());
 		while ($width <= $pos{w} && $word) {
@@ -88,8 +96,11 @@ sub add {
 		$ypos -= $pos{l};
 	}
 
+	$file->page->y($file->page->h - (($ypos + $pos{l}) - $self->margin));
+
 	if (!$self->overflow && scalar @words) {
-		die "Too many words to fit the max height: $pos{h} and width: $pos{w} overflow:" . join " ", @words;
+		$file->add_page();
+		return $self->add($file, text => join " ", @words);
 	}
 
 	return $file;
